@@ -1,15 +1,9 @@
-#' @export
-print.Treee <- function(x, ...){
-  print(x$treee)
-  invisible(x)
-}
-
-
 #' @export
 print.TreeeNode <- function(x, ...){
   cat(paste0("Node ",x$currentIndex,":\n"))
   cat("Number of observations: ", length(x$idxRow), "\n")
   # cat("Number of variables: ", length(x$idxCol), "\n")
+  cat("Parent:", x$parent, "\n")
   cat("Children:", x$children, "\n")
   cat("Node model:", x$nodeModel, "\n")
   # cat("Current Loss:", x$currentLoss, "\n")
@@ -21,8 +15,6 @@ print.TreeeNode <- function(x, ...){
 #' @export
 summary.TreeeNode <- function(object, ...){
   # just print out everything besides some super long info
-  object$idxRow <- object$idxCol <- object$nodePredict <- object$misReference <- NULL
-  # class(object) <- "summary.TreeeNode"
-  # return(object)
+  object$idxRow <- object$idxCol <- object$nodePredict <- object$splitFun <- NULL
   return(unclass(object))
 }
